@@ -7,6 +7,7 @@ Wisdom is the user interaction with Whatify wisdom, it contains
 #
 # ‘Prediction’ API includes querying of predictions (Get, List and Delete) and creating a Prediction to get predictions
 # on existing Ensembles and uploaded Datasources.
+import json
 import os
 from typing import Dict, List
 
@@ -53,7 +54,7 @@ class Wisdom(APIResource):
         return response
 
     @classmethod
-    def delete(cls, id: int, api_key: str = None) -> WhatifyResponse:
+    def delete_wisdom(cls, id: int, api_key: str = None) -> WhatifyResponse:
         """
         Deletes a specific Wisdom.
 
@@ -66,4 +67,48 @@ class Wisdom(APIResource):
         """
         return cls._delete(id, api_key)
 
+    @classmethod
+    def create_wisdom(cls, name: str, user_id: int, template_id: int, user_input: str, status: str = None,
+                      email_client: str = None, is_internal_user: bool = None, foresight_limit: int = None,
+                      producer: str = None, user_context: str = None, users_in_account: str = None,
+                      logger: str = None, api_key: str = None) -> WhatifyResponse:
+        """
+        Create Wisdom for current user
+
+        :param name:
+        :param user_id:
+        :param template_id:
+        :param user_input:
+        :return:
+            WhatifyResponse: Wisdom ID, if successful
+        """
+        data = {
+            "name": name,
+            "user_input": json.dumps(user_input),
+            "user_id": user_id,
+            "template_id": template_id
+        }
+
+        requestor = APIRequestor()
+        response = requestor.post(url=cls._CLASS_PREFIX, params=data, api_key=api_key)
+        # response = requestor.post(url=cls._CLASS_PREFIX, body=data, api_key=api_key)
+        return response['id']
+
+    @classmethod
+    def update_wisdom(cls, id: int, data: str, api_key: str = None) -> WhatifyResponse:
+        """
+        update wisdom by given data
+
+        :param id:
+        :param data:
+        :param api_key:
+        :return:
+        """
+
+        requestor = APIRequestor()
+        url = '{prefix}/{id}'.format(prefix=cls._CLASS_PREFIX, id=id)
+        response = requestor.patch(url=url, body=data, api_key=api_key)
+        return response
+
+
 
