@@ -412,6 +412,60 @@ class MyWhatify:
             error_message = predict_results['error_message']
         return error_message
 
+    #############################
+    ###        Wisdoms        ###
+    #############################
+
+    @classmethod
+    def create_wisdom(cls, name: str, template_id: int, user_input: str, user_id: int = None, user_token: str = None):
+        """
+        create wisdom
+
+        :param name (str): new name of the wisdom
+        :param template_id (int): the template number for the new wisdom
+        :param user_input (Dict): contain the wisdom data
+        :param user_id (Optional [int]) : user id to set the wisdom, else we take from the exist user
+        :param user_token (Optional[str]): Explicit `user_token`, not required, if `MyWhatify.login()` was run prior
+        :return:
+
+        wisdom ID
+        """
+        with allure.step(' '.join(['creating wisdom name:', str(name), 'template_id:', str(template_id), 'user_input:',
+                                   str(user_input)])):
+            wisdom_id = my_toolkit.Wisdom.create_wisdom(name=name, user_id=user_id if user_id else cls.get_user_id(),
+                                                        template_id=template_id, user_input=user_input,
+                                                        api_key=user_token)
+        return wisdom_id
+
+    @classmethod
+    def update_wisdom(cls, wisdom_id: int, wisdom_data: str, user_token: str = None):
+        """
+        update wisdom
+
+        :param wisdom_id (int): the id of the wisdom we want to change
+        :param wisdom_data (str): the content we want to change in the wisdom
+        :param user_token (Optional[str]): Explicit `user_token`, not required, if `MyWhatify.login()` was run prior
+        :return:
+        respone Succeed \ Failed
+        """
+        with allure.step(' '.join(['updating wisdom ID:', str(wisdom_id), 'with:', str(wisdom_data)])):
+            response = my_toolkit.Wisdom.update_wisdom(id=wisdom_id, data=wisdom_data, api_key=user_token)
+        return response
+
+    @classmethod
+    def delete_wisdom(cls, wisdom_id: int, user_token: str = None):
+        """
+        delete wisdom
+
+        :param wisdom_id (int): the wisdom ID to delete
+        :param user_token (Optional[str]): Explicit `user_token`, not required, if `MyWhatify.login()` was run prior
+        :return:
+        respone Succeed \ Failed
+        """
+        with allure.step(' '.join(['Deleting wisdom ID:', str(wisdom_id)])):
+            response = my_toolkit.Wisdom.delete_wisdom(id=wisdom_id, api_key=user_token)
+        return response
+
     @classmethod
     def get_wisdom_list(cls):
         with allure.step('getting wisdom list'):
